Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/dtexp/__init__.py | 4 | 0 | 0 | 100%
src/dtexp/addition.py | 5 | 0 | 0 | 100%
src/dtexp/conditions.py | 72 | 0 | 0 | 100%
src/dtexp/exceptions.py | 2 | 0 | 0 | 100%
src/dtexp/parse_expression.py | 112 | 0 | 0 | 100%
src/dtexp/parse_timestamp.py | 39 | 0 | 0 | 100%
Total | 234 | 0 | 0 | 100%

No items found using the specified filter.